==> openshift-model-console-6.8.0-sources.jar: io/fabric8/openshift/api/model/console/v1/ApplicationMenuSpecFluent.java <==
package io.fabric8.openshift.api.model.console.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class ApplicationMenuSpecFluent<A extends ApplicationMenuSpecFluent<A>> extends BaseFluent<A>{
  public ApplicationMenuSpecFluent() {
  }
  public ApplicationMenuSpecFluent(ApplicationMenuSpec instance) {
    instance = (instance != null ? instance : new ApplicationMenuSpec());

    if (instance != null) {
      this.withImageURL(instance.getImageURL());
      this.withSection(instance.getSection());
      this.withImageURL(instance.getImageURL());
      this.withSection(instance.getSection());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
  }
  private String imageURL;
  private String section;
  private Map<String,Object> additionalProperties;
  public String getImageURL() {
    return this.imageURL;
  }
  public A withImageURL(String imageURL) {
    this.imageURL=imageURL; return (A) this;
  }
  public boolean hasImageURL() {
    return this.imageURL != null;
  }
  public String getSection() {
    return this.section;
  }
  public A withSection(String section) {
    this.section=section; return (A) this;
  }
  public boolean hasSection() {
    return this.section != null;
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ApplicationMenuSpecFluent that = (ApplicationMenuSpecFluent) o;
    if (!java.util.Objects.equals(imageURL, that.imageURL)) return false;

    if (!java.util.Objects.equals(section, that.section)) return false;

    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(imageURL,  section,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (imageURL != null) { sb.append("imageURL:"); sb.append(imageURL + ","); }
    if (section != null) { sb.append("section:"); sb.append(section + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  
}

==> openshift-model-console-6.9.0-sources.jar: io/fabric8/openshift/api/model/console/v1/ApplicationMenuSpecFluent.java <==
package io.fabric8.openshift.api.model.console.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.util.Map;
import java.util.LinkedHashMap;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class ApplicationMenuSpecFluent<A extends ApplicationMenuSpecFluent<A>> extends BaseFluent<A>{
  public ApplicationMenuSpecFluent() {
  }
  
  public ApplicationMenuSpecFluent(ApplicationMenuSpec instance) {
    this.copyInstance(instance);
  }
  private String imageURL;
  private String section;
  private Map<String,Object> additionalProperties;
  
  protected void copyInstance(ApplicationMenuSpec instance) {
    instance = (instance != null ? instance : new ApplicationMenuSpec());
  
    if (instance != null) {
        this.withImageURL(instance.getImageURL());
        this.withSection(instance.getSection());
        this.withImageURL(instance.getImageURL());
        this.withSection(instance.getSection());
        this.withAdditionalProperties(instance.getAdditionalProperties());
      }
  }
  
  public String getImageURL() {
    return this.imageURL;
  }
  
  public A withImageURL(String imageURL) {
    this.imageURL=imageURL; return (A) this;
  }
  
  public boolean hasImageURL() {
    return this.imageURL != null;
  }
  
  public String getSection() {
    return this.section;
  }
  
  public A withSection(String section) {
    this.section=section; return (A) this;
  }
  
  public boolean hasSection() {
    return this.section != null;
  }
  
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ApplicationMenuSpecFluent that = (ApplicationMenuSpecFluent) o;
    if (!java.util.Objects.equals(imageURL, that.imageURL)) return false;
  
    if (!java.util.Objects.equals(section, that.section)) return false;
  
    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(imageURL,  section,  additionalProperties,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (imageURL != null) { sb.append("imageURL:"); sb.append(imageURL + ","); }
    if (section != null) { sb.append("section:"); sb.append(section + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  

}
